@@ -128,6 +128,17 @@
 #define VERIFY_SIZE_NOT_NULL(x) \
     SIZE_NOT_NULL_(VERIFY, x)
 
+#define UINT_AS_UCHAR_(m, x)               \
+    ({                                     \
+        STATIC(TYPEOF_IS_UNSIGNED_INT(x)); \
+        m((x) <= UCHAR_MAX);               \
+        (uchar_t) (x);                     \
+    })
+#define VERIFY_UINT_AS_UCHAR(x) \
+    UINT_AS_UCHAR_(VERIFY, x)
+#define UINT_AS_UCHAR(x) \
+    UINT_AS_UCHAR_(ASSERT, x)
+
 #define UINT_TO_SIZE(x)                                       \
     ({                                                        \
         STATIC(TYPE_UNSIGNED_INT_MAX(TYPEOF(x)) <= SIZE_MAX); \
