@@ -1,4 +1,4 @@
-// Copyright (C) 2016, 2017, 2018  Stefan Vargyas
+// Copyright (C) 2016, 2017, 2018, 2019  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -17,9 +17,12 @@
 
 #include "config.h"
 
+#define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
+#include <string.h>
+#include <time.h>
 
 #if !defined(CONFIG_DYNAMIC_LINKER) && \
     !defined(JSON_NO_LIB_MAIN)
@@ -28,17 +31,19 @@
 
 #ifndef JSON_NO_LIB_MAIN
 #include <unistd.h>
-#include "json.h"
 #endif
 
+#include "json.h"
+
 #include "int-traits.h"
+#include "ptr-traits.h"
 #include "common.h"
 
 static const char program[] = STRINGIFY(PROGRAM);
 
 #ifndef JSON_NO_LIB_MAIN
 static const char license[] =
-"Copyright (C) 2016, 2017, 2018  Stefan Vargyas.\n"
+"Copyright (C) 2016, 2017, 2018, 2019  Stefan Vargyas.\n"
 "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n"
 "This is free software: you are free to change and redistribute it.\n"
 "There is NO WARRANTY, to the extent permitted by law.\n";
@@ -187,12 +192,85 @@ size_t json_timeval_to_usecs(
     return s + u;
 }
 
+bool json_get_current_time(char* buf, size_t len)
+{
+    struct tm m;
+    time_t t;
+    size_t s;
+
+    t = time(NULL);
+    if (localtime_r(&t, &m) == NULL)
+        return false;
+
+    s = strftime(
+        buf, len,
+        "%a %b %e %H:%M:%S %Z %Y",
+        &m);
+    ASSERT(s < len);
+
+    return s > 0;
+}
+
+size_t json_text_count(
+    const uchar_t* buf, size_t len,
+    uchar_t ch)
+{
+    const uchar_t *b = buf, *p;
+    size_t l = len, n = 0, d;
+
+    while ((p = memchr(b, ch, l))) {
+        d = PTR_DIFF(p + 1, b);
+        SIZE_SUB_EQ(l, d);
+        b = p + 1;
+        n ++;
+    }
+
+    return n;
+}
+
+size_t json_text_update_pos(
+    struct json_text_pos_t* pos,
+    const uchar_t* buf,
+    size_t len)
+{
+    const uchar_t* p;
+    size_t n;
+
+    if (!(n = json_text_count(
+                buf, len, '\n'))) {
+        ASSERT_SIZE_ADD_NO_OVERFLOW(
+            pos->col, len);
+        pos->col += len;
+    }
+    else {
+        ASSERT_SIZE_ADD_NO_OVERFLOW(
+            pos->line, n);
+        pos->line += n;
+
+        p = memrchr(buf, '\n', len);
+        ASSERT(p != NULL);
+
+        n = PTR_DIFF(p, buf);
+        ASSERT(n < len);
+
+        pos->col = len - n;
+    }
+
+    return n;
+}
+
 #ifndef JSON_NO_LIB_MAIN
 
-const char json_interp[]
+JSON_API const char json_interp[]
     __attribute__((section(".interp"))) =
     CONFIG_DYNAMIC_LINKER;
 
+#ifndef JSON_DEBUG
+#define JSON_DEBUG_STATE "disabled"
+#else
+#define JSON_DEBUG_STATE "enabled"
+#endif
+
 void json_main(void)
     NORETURN;
 
@@ -208,17 +286,11 @@ void json_main(void)
     fprintf(stdout,
         "%s: version: %u.%u.%u\n"
         "%s: build: %s\n"
-        "%s: JSON_DEBUG is %sabled\n\n%s",
+        "%s: JSON_DEBUG is " JSON_DEBUG_STATE "\n\n%s",
         program, v.major, v.minor, v.patch,
         program, b,
         program,
-#ifdef JSON_DEBUG
-        "en",
-#else
-        "dis",
-#endif
-        license
-    );
+        license);
     fflush(stdout);
 
     _exit(0);
