@@ -128,7 +128,7 @@ error:
     return false;
 }
 
-void file_buf_read(struct file_buf_t* buf)
+static void file_buf_read(struct file_buf_t* buf)
 {
     struct stat st;
     int fd;
