@@ -903,6 +903,8 @@ static bool json_parse_number_token(
         n ++;
     }
 loop_out:
+    // stev: buf->ptr >= buf->end => part->state != JSON_NUM_STATE(error)
+    ASSERT(buf->ptr < buf->end || part->state != JSON_NUM_STATE(error));
 
     ASSERT_SIZE_ADD_NO_OVERFLOW(obj->current_pos.col, n);
     obj->current_pos.col += n;
@@ -916,8 +918,7 @@ loop_out:
         obj->current_tok.part.type = json_token_complete_part;
         return true;
     }
-    if (part->state != JSON_NUM_STATE(error) &&
-        buf->ptr >= buf->end)
+    if (buf->ptr >= buf->end)
         return true;
 
     return JSON_LEX_ERROR(invalid_number_literal);
@@ -1132,6 +1133,8 @@ static bool json_parse_string_token(
         n ++;
     }
 loop_out:
+    // stev: buf->ptr >= buf->end => part->state != JSON_STR_STATE(error)
+    ASSERT(buf->ptr < buf->end || part->state != JSON_STR_STATE(error));
 
     ASSERT_SIZE_ADD_NO_OVERFLOW(obj->current_pos.col, n);
     obj->current_pos.col += n;
@@ -1156,8 +1159,7 @@ loop_out:
         obj->current_tok.part.type = json_token_complete_part;
         return true;
     }
-    if (part->state != JSON_STR_STATE(error) &&
-        buf->ptr >= buf->end)
+    if (buf->ptr >= buf->end)
         return true;
 
     return JSON_LEX_ERROR(invalid_string_literal);
@@ -1283,6 +1285,8 @@ static bool json_parse_rstring_token(
         n ++;
     }
 loop_out:
+    // stev: buf->ptr >= buf->end => part->state != JSON_RSTR_STATE(error)
+    ASSERT(buf->ptr < buf->end || part->state != JSON_RSTR_STATE(error));
 
     json_text_update_pos(&obj->current_pos, ptr, n);
 
@@ -1314,8 +1318,7 @@ loop_out:
         obj->current_tok.part.type = json_token_complete_part;
         return true;
     }
-    if (part->state != JSON_RSTR_STATE(error) &&
-        buf->ptr >= buf->end)
+    if (buf->ptr >= buf->end)
         return true;
 
     return JSON_LEX_ERROR(invalid_rstring_literal);
