@@ -1,4 +1,4 @@
-// Copyright (C) 2016, 2017, 2018  Stefan Vargyas
+// Copyright (C) 2016, 2017, 2018, 2019  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -35,6 +35,9 @@ JSON_API size_t pretty_print_char(
     FILE* file, char ch, size_t flags);
 JSON_API size_t pretty_print_string(
     FILE* file, const uchar_t* str, size_t len, size_t flags);
+JSON_API size_t pretty_print_strings(
+    FILE* file, const char* const* strs, size_t n_strs,
+    const char* name, size_t width, size_t flags);
 
 enum pretty_print_repr_flags_t {
     pretty_print_repr_quote_non_print = 1U << 0,
