@@ -1,4 +1,4 @@
-// Copyright (C) 2016, 2017, 2018  Stefan Vargyas
+// Copyright (C) 2016, 2017, 2018, 2019  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -28,6 +28,32 @@
 
 #define MEM_ALIGNOF(t) __alignof__(t)
 
+// stev: cast 'T* const*' to 'T const* const*';
+// note that ISO C++ allow such casts by way of
+// its relaxed albeit more involved rules; ISO C
+// is considering the two double pointer types
+// incompatible due to its rougher yet simpler
+// typing rules
+#define PTR_CONST_PTR_CAST(p, t)         \
+    (                                    \
+        STATIC(TYPEOF_IS(p, t* const*)), \
+        (t const* const*) (p)            \
+    )
+
+// stev: cast 'T**' to 'T const* const*'
+#define PTR_PTR_CAST(p, t)         \
+    (                              \
+        STATIC(TYPEOF_IS(p, t**)), \
+        (t const* const*) (p)      \
+    )
+
+// stev: cast 'T const* const*' to 'T**'
+#define CONST_PTR_CONST_PTR_CAST(p, t)         \
+    (                                          \
+        STATIC(TYPEOF_IS(p, t const* const*)), \
+        (t**) (p)                              \
+    )
+
 #define PTR_TO_SIZE(p)                              \
     (                                               \
         STATIC(CONFIG_PTR_TO_INT_IDENTOP),          \
@@ -107,6 +133,34 @@
         TYPEOF_IS(x, uchar_t)   \
     )
 
+#define PTR_XCHAR_TO_YCHAR_CAST_(x, y, p, q) \
+    (                                        \
+        STATIC(                              \
+            TYPEOF_IS(p, q x*) ||            \
+            TYPEOF_IS(p, q x[])),            \
+        (q y*) (p)                           \
+    )
+#define PTR_CHAR_CAST_(p, q) \
+    PTR_XCHAR_TO_YCHAR_CAST_(uchar_t, char, p, q)
+#define PTR_UCHAR_CAST_(p, q) \
+    PTR_XCHAR_TO_YCHAR_CAST_(char, uchar_t, p, q)
+
+// stev: cast 'uchar_t const*' to 'char const*'
+#define PTR_CHAR_CAST_CONST(x) \
+    PTR_CHAR_CAST_(x, const)
+
+// stev: cast 'uchar_t*' to 'char*'
+#define PTR_CHAR_CAST(x) \
+    PTR_CHAR_CAST_(x, )
+
+// stev: cast 'char const*' to 'uchar_t const*'
+#define PTR_UCHAR_CAST_CONST(x) \
+    PTR_UCHAR_CAST_(x, const)
+
+// stev: cast 'char*' to 'uchar_t*'
+#define PTR_UCHAR_CAST(x) \
+    PTR_UCHAR_CAST_(x, )
+
 #define ARRAY_SIZE(a) (sizeof(a) / sizeof((a)[0]))
 
 #define ARRAY_INDEX(a, i)                  \
