@@ -1,4 +1,4 @@
-// Copyright (C) 2016, 2017, 2018  Stefan Vargyas
+// Copyright (C) 2016, 2017, 2018, 2019  Stefan Vargyas
 // 
 // This file is part of Json-Type.
 // 
@@ -20,6 +20,26 @@
 
 #include "lib/json.h"
 
+#include "json-filters.h"
+
+enum json_intf_config_param_t
+{
+    // stev: json.h config parameters:
+    json_intf_allow_empty_input_config,
+    json_intf_allow_raw_strings_config,
+    json_intf_allow_literal_value_config,
+    json_intf_allow_multi_objects_config,
+    json_intf_allow_surrogate_pairs_config,
+    json_intf_disallow_unicode_esc_config,
+    json_intf_disallow_non_ascii_config,
+    json_intf_validate_utf8_config,
+    json_intf_trim_spaces_config,
+    json_intf_quote_text_config,
+
+    // stev: json-filters.h config parameters:
+    json_intf_verbose_error_config,
+};
+
 struct json_intf_t;
 
 struct json_intf_t* json_intf_create_obj(
@@ -39,18 +59,24 @@ struct json_intf_t* json_intf_create_text_type_lib(
     const struct json_type_lib_sizes_t* sizes);
 struct json_intf_t* json_intf_create_sobj_type_lib(
     const char* lib_name, const struct json_type_lib_sizes_t* sizes);
+struct json_intf_t* json_intf_create_filter_lib(
+    const struct options_filter_t* opts);
 struct json_intf_t* json_intf_create_esc(
     const struct json_esc_sizes_t* sizes);
 
 void json_intf_destroy(struct json_intf_t*);
 
 void json_intf_config_set_param(
-    struct json_intf_t*, enum json_config_param_t param, bool val);
+    struct json_intf_t*, enum json_intf_config_param_t param, bool val);
 
 enum json_parse_status_t json_intf_parse(struct json_intf_t*,
     const uchar_t*, size_t);
 enum json_parse_status_t json_intf_parse_done(struct json_intf_t*);
 
+struct json_text_pos_t json_intf_get_token_pos(struct json_intf_t*);
+
+const uchar_t* json_intf_get_token_delim(struct json_intf_t*);
+
 bool json_intf_get_is_error(struct json_intf_t*);
 struct json_error_pos_t json_intf_get_error_pos(struct json_intf_t*);
 const struct json_file_info_t* json_intf_get_error_file(
@@ -72,6 +98,9 @@ struct json_type_t* json_intf_get_as_type(
 struct json_type_lib_t* json_intf_get_as_type_lib(
     struct json_intf_t*);
 
+struct json_filter_lib_t* json_intf_get_as_filter_lib(
+    struct json_intf_t*);
+
 struct json_esc_t* json_intf_get_as_esc(
     struct json_intf_t*);
 
