@@ -26,11 +26,6 @@
 #include "common.h"
 #include "json2.h"
 
-#ifdef DEBUG
-#define PRINT_DEBUG_COND this->debug
-#include "debug.h"
-#endif
-
 // stev: TODO: add an option to output object types in the form of
 // PATH_TO_OBJECT@TYPE=VALUE, where TYPE is '0' for 'null', 'b' for
 // 'boolean', 'n' for 'number', 's' for 'string', 'o' for 'object' and
